==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ForceIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ForceIndexIndicatorDescription } from "./ForceIndexIndicatorDescription";
/**
 * @hidden
 */
export let ForceIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ForceIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ForceIndexIndicatorDescriptionMetadata.a == null) {
                ForceIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ForceIndexIndicatorDescriptionMetadata.c(ForceIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(ForceIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(ForceIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            ForceIndexIndicatorDescriptionMetadata.b(a);
            a.ac("ForceIndexIndicator", () => new ForceIndexIndicatorDescription());
            a.ab("ForceIndexIndicator", ForceIndexIndicatorDescriptionMetadata.a);
        }
    }
    ForceIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ForceIndexIndicatorDescriptionMetadata, 'ForceIndexIndicatorDescriptionMetadata');
    ForceIndexIndicatorDescriptionMetadata.a = null;
    return ForceIndexIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ForceIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ForceIndexIndicatorDescription } from "./ForceIndexIndicatorDescription";
/**
 * @hidden
 */
export let ForceIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ForceIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ForceIndexIndicatorDescriptionMetadata.a == null) {
                ForceIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ForceIndexIndicatorDescriptionMetadata.c(ForceIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(ForceIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(ForceIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            ForceIndexIndicatorDescriptionMetadata.b(a);
            a.ae("ForceIndexIndicator", () => new ForceIndexIndicatorDescription());
            a.ad("ForceIndexIndicator", ForceIndexIndicatorDescriptionMetadata.a);
        }
    }
    ForceIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ForceIndexIndicatorDescriptionMetadata, 'ForceIndexIndicatorDescriptionMetadata');
    ForceIndexIndicatorDescriptionMetadata.a = null;
    return ForceIndexIndicatorDescriptionMetadata;
})();
